@@ -5,6 +5,12 @@ try {
     window.outerHeight = 896
     window.outerWidth = 414
     window.innerWidth = 414
+    Object.defineProperty(Object.getPrototypeOf(document.body), 'clientWidth', {
+        get: () => 414,
+    })
+     Object.defineProperty(Object.getPrototypeOf(document.body), 'clientHeight', {
+        get: () => 1361,
+    })
     Object.defineProperty(Object.getPrototypeOf(screen), 'width', {
         get: () => 414,
     })
